@@ -7,8 +7,8 @@
 ;; Keywords: tools, accessibility
 ;; URL: https://gitlab.com/michelangelo-rodriguez/greader
 
-;; Package-Version: 20251125.859
-;; Package-Revision: b25974aeae49
+;; Package-Version: 20260103.2206
+;; Package-Revision: 66a405e49df0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -686,7 +686,9 @@ calling all the hooks."
   (greader-set-greader-keymap)
   (greader-tts-stop)
   (run-hooks 'greader-after-stop-hook)
-  (when (or greader-dict-mode greader-dict-toggle-filters)
+  (when (and (featurep 'greader-dict)
+             (or greader-dict-mode
+                 greader-dict-toggle-filters))
     (greader-dict--update)))
 
 (defun greader-debug (arg)
